import os, re
from bs4 import BeautifulSoup
import datetime
import unicodedata
import string

def nombre_archivo(cadena):
    """Devolver nombre del archivo.
    Normaliza el nombre del documento reemplazando tildes y otros caracteres
    no ASCII, también reemplaza espacios en blanco por -."""
    cadena = unicodedata.normalize('NFKD', cadena)
    valid_chars = "-_ %s%s" % (string.ascii_letters, string.digits)
    nombre = ''.join(c for c in cadena if c in valid_chars)
    nombre = nombre.replace(' ','-').strip().lower()
    return nombre

#Busco los archivos que voy a trabajar

listado = []
directorio_libros = 'C:/Users/Edgar/sitio-viejo/public_html/libros/'
for file in os.listdir(directorio_libros):
    #Sólo archivos html
    if file.endswith('.html'):
        with open(directorio_libros + file, 'r', encoding='utf8') as archivo:
            #Obtengo el contenido del primer archivo
            contenido_html = archivo.read()
            soup = BeautifulSoup(contenido_html, 'html.parser')
            #Comienzo a obtener los contenidos del título, autor, fecha y texto de la opinión usando BS4
            cuerpo = soup.find(id="cuerpo")
            titulo = cuerpo.h1.text.strip();
            autor = cuerpo.find_all('p', limit=1)[-1].strong.next_sibling.strip().replace(": ", "")
            fecha = cuerpo.find_all('p', limit=2)[-1].strong.next_sibling.strip().replace(": ", "")
            #Algunas de mis fechas eran AAAA/MM/DD
            r = re.compile('\d{4}/\d{2}/\d{2}')
            if r.match(fecha):
                fecha = datetime.datetime.strptime(fecha,"%Y/%m/%d").strftime('%Y-%m-%d')
            #Agrego zona horaria para Guatemala
            fecha = fecha + 'T00:00:00-06:00'
            opinion = cuerpo.find(id="opinion").text.strip();
            #Con los contenidos ya extraídos los voy a escribir al archivo final usando una plantilla en markdown
            with open('plantilla_libros.md', 'r', encoding='utf8') as nuevo:
                contenido = nuevo.read().replace('{.titulo}', titulo)
                contenido = contenido.replace('{.fecha}', fecha)
                contenido = contenido.replace('{.autor}', autor)
                contenido = contenido.replace('{.opinion}', opinion)
            with open('libros/' + nombre_archivo(titulo) + '.md', 'w', encoding='utf8') as libro:
                libro.write(contenido)